@@ -1,6 +1,8 @@
 from matplotlib import pyplot as plt
 import pandas as pd
 import os
+import astropy.io.fits as fits
+from DensityClust.clustring_subfunc import *
 
 
 def make_plot_wcs_1(data_name, outcat_wcs_name):
